@@ -30,6 +30,7 @@ my %license_table = (
     'aacid'     => ['gplv23', 'lgplv23', 'gplv2+', 'lgplv2+', '+eV' ],
     'abryant'   => ['gplv23', 'lgplv23', 'gplv2+', 'lgplv2+', '+eV' ],
     'adawit'    => ['gplv23', 'lgplv23',                      '+eV' ],
+    'alexmerry' => ['gplv23', 'lgplv23', 'gplv2+', 'lgplv2+', '+eV' ],
     'alund'     => ['gplv23', 'lgplv23', 'gplv2+', 'lgplv2+', '+eV' ],
     'amth'      => ['gplv23', 'lgplv23', 'gplv2+', 'lgplv2+', '+eV' ],
     'aseigo'    => ['gplv23', 'lgplv23', 'gplv2+', 'lgplv2+', '+eV' ],
@@ -77,6 +78,7 @@ my %license_table = (
     'kloecker'  => ['gplv23', 'lgplv23', 'gplv2+', 'lgplv2+'        ],
     'kossebau'  => ['gplv23', 'lgplv23', 'gplv2+', 'lgplv2+', '+eV' ],
     'kylafas'   => ['gplv23', 'lgplv23', 'gplv2+', 'lgplv2+', '+eV' ],
+    'lueck'     => ['gplv23', 'lgplv23', 'gplv2+', 'lgplv2+', '+eV' ],
     'mbritton'  => ['gplv23', 'lgplv23', 'gplv2+', 'lgplv2+', '+eV' ],
  'michaelhowell'=> ['gplv23', 'lgplv23', 'gplv2+', 'lgplv2+', '+eV' ],
     'mirko'     => ['gplv23', 'lgplv23', 'gplv2+', 'lgplv2+', '+eV' ],
@@ -99,12 +101,14 @@ my %license_table = (
     'robbilla'  => ['gplv23', 'lgplv23', 'gplv2+', 'lgplv2+'        ],
    'rpreukschas'=> ['gplv23', 'lgplv23', 'gplv2+', 'lgplv2+', '+eV' ],
     'sanders'   => ['gplv23', 'lgplv23', 'gplv2+', 'lgplv2+', '+eV' ],
+    'sars'      => ['gplv23', 'lgplv23',                      '+eV' ],
     'sping'     => ['gplv23', 'lgplv23', 'gplv2+', 'lgplv2+'        ],
     'taj'       => ['gplv23', 'lgplv23', 'gplv2+', 'lgplv2+'        ],
     'tenharmsel'=> ['gplv23', 'lgplv23', 'gplv2+', 'lgplv2+', '+eV' ],
     'teske'     => ['gplv23', 'lgplv23',                            ],
     'tfry'      => ['gplv23', 'lgplv23', 'gplv2+', 'lgplv2+'        ],
     'tmcguire'  => ['gplv23', 'lgplv23', 'gplv2+', 'lgplv2+', '+eV' ],
+    'turbov'    => ['gplv23', 'lgplv23', 'gplv2+', 'lgplv2+', '+eV' ],
     'uga'       => ['gplv23', 'lgplv23', 'gplv2+', 'lgplv2+', '+eV' ],
     'vkrause'   => ['gplv23', 'lgplv23', 'gplv2+', 'lgplv2+'        ],
     'waba'      => ['gplv23', 'lgplv23',                      '+eV' ],
@@ -121,7 +125,6 @@ my %license_table = (
     ### to the above part of the table so that we don't ask them again.
     'adridg'    => ['gplv23', 'lgplv23'                      ],
     'ahartmetz' => ['gplv23', 'lgplv23', 'gplv2+', 'lgplv2+' ],
-    'alexmerry' => ['gplv23', 'lgplv23', 'gplv2+', 'lgplv2+' ],
     'amantia'   => ['gplv23', 'lgplv23'                      ],
     'annma'     => ['gplv23', 'lgplv23', 'gplv2+', 'lgplv2+' ],
     'apaku'     => ['gplv23', 'lgplv23', 'gplv2+', 'lgplv2+' ],
